package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenDeviceSensorRecord;
import com.bonus.canteen.core.kitchen.service.IKitchenDeviceSensorRecordService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房后场设备传感器记录Controller
 * 
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "厨房后场设备传感器记录接口")
@RestController
@RequestMapping("/kitchen_device_sensor_record")
public class KitchenDeviceSensorRecordController extends BaseController {
    @Autowired
    private IKitchenDeviceSensorRecordService kitchenDeviceSensorRecordService;

    /**
     * 查询厨房后场设备传感器记录列表
     */
    @ApiOperation(value = "查询厨房后场设备传感器记录列表")
    //@RequiresPermissions("kitchen:record:list")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody @Valid KitchenDeviceSensorRecord kitchenDeviceSensorRecord) {
        startPage();
        List<KitchenDeviceSensorRecord> list = kitchenDeviceSensorRecordService.selectKitchenDeviceSensorRecordList(kitchenDeviceSensorRecord);
        return getDataTable(list);
    }

    /**
     * 导出厨房后场设备传感器记录列表
     */
    @ApiOperation(value = "导出厨房后场设备传感器记录列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:export")
    @SysLog(title = "厨房后场设备传感器记录", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出厨房后场设备传感器记录")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenDeviceSensorRecord kitchenDeviceSensorRecord) {
        List<KitchenDeviceSensorRecord> list = kitchenDeviceSensorRecordService.selectKitchenDeviceSensorRecordList(kitchenDeviceSensorRecord);
        ExcelUtil<KitchenDeviceSensorRecord> util = new ExcelUtil<KitchenDeviceSensorRecord>(KitchenDeviceSensorRecord.class);
        util.exportExcel(response, list, "厨房后场设备传感器记录数据");
    }

    /**
     * 获取厨房后场设备传感器记录详细信息
     */
    @ApiOperation(value = "获取厨房后场设备传感器记录详细信息")
    //@RequiresPermissions("kitchen:record:query")
    @GetMapping(value = "/{recordId}")
    public AjaxResult getInfo(@PathVariable("recordId") Long recordId) {
        return success(kitchenDeviceSensorRecordService.selectKitchenDeviceSensorRecordByRecordId(recordId));
    }

    /**
     * 新增厨房后场设备传感器记录
     */
    @ApiOperation(value = "新增厨房后场设备传感器记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:add")
    @SysLog(title = "厨房后场设备传感器记录", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增厨房后场设备传感器记录")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenDeviceSensorRecord kitchenDeviceSensorRecord) {
        try {
            return toAjax(kitchenDeviceSensorRecordService.insertKitchenDeviceSensorRecord(kitchenDeviceSensorRecord));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房后场设备传感器记录
     */
    @ApiOperation(value = "修改厨房后场设备传感器记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:edit")
    @SysLog(title = "厨房后场设备传感器记录", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改厨房后场设备传感器记录")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenDeviceSensorRecord kitchenDeviceSensorRecord) {
        try {
            return toAjax(kitchenDeviceSensorRecordService.updateKitchenDeviceSensorRecord(kitchenDeviceSensorRecord));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除厨房后场设备传感器记录
     */
    @ApiOperation(value = "删除厨房后场设备传感器记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:remove")
    @SysLog(title = "厨房后场设备传感器记录", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除厨房后场设备传感器记录")
	@PostMapping("/del/{recordIds}")
    public AjaxResult remove(@PathVariable Long[] recordIds) {
        return toAjax(kitchenDeviceSensorRecordService.deleteKitchenDeviceSensorRecordByRecordIds(recordIds));
    }
}
